import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  scaleOrdinal,
  axisLeft,
  axisBottom,
  rgb,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const title = 'Homeless Population in New York (2009-2012)';
  
  // Common dimensions
  const yValue = (d) => d.Population;
  const xValue = (d) => d.Area;
  const xDiv = (d) => d.Year;

  // Margin Data
  const margin = {
    top: 100,
    right: 50,
    bottom: 60,
    left: 150,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  // Scale delcarations
  const yScale = scaleLinear()
    .domain([0, Math.max(max(data, yValue))])
    .range([innerHeight, 0]);

  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.2);

  const subScale = scaleBand()
    .domain(data.map(xDiv))
    .range([0, xScale.bandwidth()])
    .padding(0.05);

  const colorScale = scaleOrdinal()
    .domain(data.map(xDiv))
    .range([
      rgb('steelblue'),
      rgb('limegreen'),
      rgb('goldenrod'),
      rgb('crimson'),
    ]);

  
  
  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`
    );

  // Draw axes
  g.append('g').call(axisLeft(yScale));
  g.append('g')
    .call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);

  
  
  // Draw bars
  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('x', (d) => xScale(xValue(d)) + subScale(xDiv(d)))
    .attr('y', (d) => yScale(yValue(d)))
    .attr('height', (d) => innerHeight - yScale(yValue(d)))
    .attr('width', subScale.bandwidth())
    .attr('fill', (d) => colorScale(xDiv(d)));
  

    g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
  		.attr('x', 10)
  		.attr('fill', 'gray')
  		.style('font-size', '2em')
      .text(title);
  
  

	// Draw Legend
	var legend = svg.selectAll('legend')
		.data(subScale.domain()).enter()
  	.append('g')
  	.attr('transform', 'translate(0, 100)')
  	.attr('opacity', 1);

  console.log(subScale.domain()[0] - 2009);
  
  legend.append('rect')
    .attr('x', 60)
  	.attr('y', d => (d - 2009) * 25)
  	.attr("width", 20)
  	.attr('height', 20)
  	.attr('fill', d => colorScale(d));
  
  legend.append('text')
  	.attr('x', 24)
  	.attr('y', d => (d - 2009) * 25 + 10)
  	.attr('dy', '.35em')
  	.style('font-size', '.9em')
  	.text(d => d);
  
  
  svg.append('text')
  	.attr('transform', 'translate(480, 480)')
  	.attr('text-anchor', 'middle')
  	.style('font-size', '.7em')
  	.text('*Surface Population');
};
	

var data=[
    {
        "Area": "*Manhattan ",
        "Year": 2009,
        "Population": 777
    },
    {
        "Area": "*Bronx ",
        "Year": 2009,
        "Population": 164
    },
    {
        "Area": "*Brooklyn ",
        "Year": 2009,
        "Population": 200
    },
    {
        "Area": "*Queens ",
        "Year": 2009,
        "Population": 98
    },
    {
        "Area": "*Staten Island ",
        "Year": 2009,
        "Population": 121
    },
    {
        "Area": "Surface Total ",
        "Year": 2009,
        "Population": 1360
    },
    {
        "Area": "Subways ",
        "Year": 2009,
        "Population": 968
    },
    {
        "Area": "Total Unsheltered  ",
        "Year": 2009,
        "Population": 2328
    },
    {
        "Area": "*Manhattan ",
        "Year": 2010,
        "Population": 1145
    },
    {
        "Area": "*Bronx ",
        "Year": 2010,
        "Population": 174
    },
    {
        "Area": "*Brooklyn ",
        "Year": 2010,
        "Population": 428
    },
    {
        "Area": "*Queens ",
        "Year": 2010,
        "Population": 112
    },
    {
        "Area": "*Staten Island ",
        "Year": 2010,
        "Population": 175
    },
    {
        "Area": "Surface Total ",
        "Year": 2010,
        "Population": 2034
    },
    {
        "Area": "Subways ",
        "Year": 2010,
        "Population": 1077
    },
    {
        "Area": "Total Unsheltered  ",
        "Year": 2010,
        "Population": 3111
    },
    {
        "Area": "*Manhattan ",
        "Year": 2011,
        "Population": 786
    },
    {
        "Area": "*Bronx ",
        "Year": 2011,
        "Population": 115
    },
    {
        "Area": "*Brooklyn ",
        "Year": 2011,
        "Population": 242
    },
    {
        "Area": "*Queens ",
        "Year": 2011,
        "Population": 102
    },
    {
        "Area": "*Staten Island ",
        "Year": 2011,
        "Population": 128
    },
    {
        "Area": "Surface Total ",
        "Year": 2011,
        "Population": 1373
    },
    {
        "Area": "Subways ",
        "Year": 2011,
        "Population": 1275
    },
    {
        "Area": "Total Unsheltered  ",
        "Year": 2011,
        "Population": 2648
    },
    {
        "Area": "*Manhattan ",
        "Year": 2012,
        "Population": 906
    },
    {
        "Area": "*Bronx ",
        "Year": 2012,
        "Population": 169
    },
    {
        "Area": "*Brooklyn ",
        "Year": 2012,
        "Population": 368
    },
    {
        "Area": "*Queens ",
        "Year": 2012,
        "Population": 86
    },
    {
        "Area": "*Staten Island ",
        "Year": 2012,
        "Population": 99
    },
    {
        "Area": "Surface Total ",
        "Year": 2012,
        "Population": 1628
    },
    {
        "Area": "Subways ",
        "Year": 2012,
        "Population": 1634
    },
    {
        "Area": "Total Unsheltered  ",
        "Year": 2012,
        "Population": 3262
    }
];
  render(data);

